# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

class GatewayModelProvider(BaseModel):
    """
    GatewayModelProvider
    """ # noqa: E501
    api_provider_id: StrictStr = Field(description="Identifier for the provider.")
    api_provider_name: Optional[StrictStr] = Field(description="Human readable provider name.")
    link: Optional[StrictStr] = Field(description="Canonical URL for the provider.")
    country_code: Optional[StrictStr] = Field(description="Provider headquarters country code.")
    endpoint: StrictStr = Field(description="Gateway endpoint served by this provider.")
    provider_model_slug: Optional[StrictStr] = Field(description="Provider specific model identifier.")
    is_active_gateway: StrictBool = Field(description="Whether the provider is currently routable via the gateway.")
    input_modalities: List[StrictStr] = Field(description="Input modalities supported by this provider-model pairing.")
    output_modalities: List[StrictStr] = Field(description="Output modalities supported by this provider-model pairing.")
    effective_from: Optional[datetime] = Field(description="Timestamp from which the pairing is effective.")
    effective_to: Optional[datetime] = Field(description="Timestamp when the pairing stops being effective.")
    __properties: ClassVar[List[str]] = ["api_provider_id", "api_provider_name", "link", "country_code", "endpoint", "provider_model_slug", "is_active_gateway", "input_modalities", "output_modalities", "effective_from", "effective_to"]

    @field_validator('endpoint')
    def endpoint_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['chat.completions', 'images.generations', 'audio.speech', 'audio.transcription', 'moderations', 'video.generation', 'embeddings', 'batch']):
            raise ValueError("must be one of enum values ('chat.completions', 'images.generations', 'audio.speech', 'audio.transcription', 'moderations', 'video.generation', 'embeddings', 'batch')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GatewayModelProvider from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if api_provider_name (nullable) is None
        # and model_fields_set contains the field
        if self.api_provider_name is None and "api_provider_name" in self.model_fields_set:
            _dict['api_provider_name'] = None

        # set to None if link (nullable) is None
        # and model_fields_set contains the field
        if self.link is None and "link" in self.model_fields_set:
            _dict['link'] = None

        # set to None if country_code (nullable) is None
        # and model_fields_set contains the field
        if self.country_code is None and "country_code" in self.model_fields_set:
            _dict['country_code'] = None

        # set to None if provider_model_slug (nullable) is None
        # and model_fields_set contains the field
        if self.provider_model_slug is None and "provider_model_slug" in self.model_fields_set:
            _dict['provider_model_slug'] = None

        # set to None if effective_from (nullable) is None
        # and model_fields_set contains the field
        if self.effective_from is None and "effective_from" in self.model_fields_set:
            _dict['effective_from'] = None

        # set to None if effective_to (nullable) is None
        # and model_fields_set contains the field
        if self.effective_to is None and "effective_to" in self.model_fields_set:
            _dict['effective_to'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GatewayModelProvider from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "api_provider_id": obj.get("api_provider_id"),
            "api_provider_name": obj.get("api_provider_name"),
            "link": obj.get("link"),
            "country_code": obj.get("country_code"),
            "endpoint": obj.get("endpoint"),
            "provider_model_slug": obj.get("provider_model_slug"),
            "is_active_gateway": obj.get("is_active_gateway"),
            "input_modalities": obj.get("input_modalities"),
            "output_modalities": obj.get("output_modalities"),
            "effective_from": obj.get("effective_from"),
            "effective_to": obj.get("effective_to")
        })
        return _obj





# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
import pprint
from pydantic import BaseModel, ConfigDict, Field, StrictStr, ValidationError, field_validator
from typing import Any, List, Optional
from ai_stats_generated.models.message_content_image_url import MessageContentImageUrl
from ai_stats_generated.models.message_content_input_audio import MessageContentInputAudio
from ai_stats_generated.models.message_content_input_video import MessageContentInputVideo
from ai_stats_generated.models.message_content_text import MessageContentText
from ai_stats_generated.models.tool_call_part import ToolCallPart
from pydantic import StrictStr, Field
from typing import Union, List, Set, Optional, Dict
from typing_extensions import Literal, Self

MESSAGECONTENTPART_ONE_OF_SCHEMAS = ["MessageContentImageUrl", "MessageContentInputAudio", "MessageContentInputVideo", "MessageContentText", "ToolCallPart"]

class MessageContentPart(BaseModel):
    """
    MessageContentPart
    """
    # data type: MessageContentText
    oneof_schema_1_validator: Optional[MessageContentText] = None
    # data type: MessageContentImageUrl
    oneof_schema_2_validator: Optional[MessageContentImageUrl] = None
    # data type: MessageContentInputAudio
    oneof_schema_3_validator: Optional[MessageContentInputAudio] = None
    # data type: MessageContentInputVideo
    oneof_schema_4_validator: Optional[MessageContentInputVideo] = None
    # data type: ToolCallPart
    oneof_schema_5_validator: Optional[ToolCallPart] = None
    actual_instance: Optional[Union[MessageContentImageUrl, MessageContentInputAudio, MessageContentInputVideo, MessageContentText, ToolCallPart]] = None
    one_of_schemas: Set[str] = { "MessageContentImageUrl", "MessageContentInputAudio", "MessageContentInputVideo", "MessageContentText", "ToolCallPart" }

    model_config = ConfigDict(
        validate_assignment=True,
        protected_namespaces=(),
    )


    discriminator_value_class_map: Dict[str, str] = {
    }

    def __init__(self, *args, **kwargs) -> None:
        if args:
            if len(args) > 1:
                raise ValueError("If a position argument is used, only 1 is allowed to set `actual_instance`")
            if kwargs:
                raise ValueError("If a position argument is used, keyword arguments cannot be used.")
            super().__init__(actual_instance=args[0])
        else:
            super().__init__(**kwargs)

    @field_validator('actual_instance')
    def actual_instance_must_validate_oneof(cls, v):
        instance = MessageContentPart.model_construct()
        error_messages = []
        match = 0
        # validate data type: MessageContentText
        if not isinstance(v, MessageContentText):
            error_messages.append(f"Error! Input type `{type(v)}` is not `MessageContentText`")
        else:
            match += 1
        # validate data type: MessageContentImageUrl
        if not isinstance(v, MessageContentImageUrl):
            error_messages.append(f"Error! Input type `{type(v)}` is not `MessageContentImageUrl`")
        else:
            match += 1
        # validate data type: MessageContentInputAudio
        if not isinstance(v, MessageContentInputAudio):
            error_messages.append(f"Error! Input type `{type(v)}` is not `MessageContentInputAudio`")
        else:
            match += 1
        # validate data type: MessageContentInputVideo
        if not isinstance(v, MessageContentInputVideo):
            error_messages.append(f"Error! Input type `{type(v)}` is not `MessageContentInputVideo`")
        else:
            match += 1
        # validate data type: ToolCallPart
        if not isinstance(v, ToolCallPart):
            error_messages.append(f"Error! Input type `{type(v)}` is not `ToolCallPart`")
        else:
            match += 1
        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when setting `actual_instance` in MessageContentPart with oneOf schemas: MessageContentImageUrl, MessageContentInputAudio, MessageContentInputVideo, MessageContentText, ToolCallPart. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when setting `actual_instance` in MessageContentPart with oneOf schemas: MessageContentImageUrl, MessageContentInputAudio, MessageContentInputVideo, MessageContentText, ToolCallPart. Details: " + ", ".join(error_messages))
        else:
            return v

    @classmethod
    def from_dict(cls, obj: Union[str, Dict[str, Any]]) -> Self:
        return cls.from_json(json.dumps(obj))

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Returns the object represented by the json string"""
        instance = cls.model_construct()
        error_messages = []
        match = 0

        # deserialize data into MessageContentText
        try:
            instance.actual_instance = MessageContentText.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into MessageContentImageUrl
        try:
            instance.actual_instance = MessageContentImageUrl.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into MessageContentInputAudio
        try:
            instance.actual_instance = MessageContentInputAudio.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into MessageContentInputVideo
        try:
            instance.actual_instance = MessageContentInputVideo.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))
        # deserialize data into ToolCallPart
        try:
            instance.actual_instance = ToolCallPart.from_json(json_str)
            match += 1
        except (ValidationError, ValueError) as e:
            error_messages.append(str(e))

        if match > 1:
            # more than 1 match
            raise ValueError("Multiple matches found when deserializing the JSON string into MessageContentPart with oneOf schemas: MessageContentImageUrl, MessageContentInputAudio, MessageContentInputVideo, MessageContentText, ToolCallPart. Details: " + ", ".join(error_messages))
        elif match == 0:
            # no match
            raise ValueError("No match found when deserializing the JSON string into MessageContentPart with oneOf schemas: MessageContentImageUrl, MessageContentInputAudio, MessageContentInputVideo, MessageContentText, ToolCallPart. Details: " + ", ".join(error_messages))
        else:
            return instance

    def to_json(self) -> str:
        """Returns the JSON representation of the actual instance"""
        if self.actual_instance is None:
            return "null"

        if hasattr(self.actual_instance, "to_json") and callable(self.actual_instance.to_json):
            return self.actual_instance.to_json()
        else:
            return json.dumps(self.actual_instance)

    def to_dict(self) -> Optional[Union[Dict[str, Any], MessageContentImageUrl, MessageContentInputAudio, MessageContentInputVideo, MessageContentText, ToolCallPart]]:
        """Returns the dict representation of the actual instance"""
        if self.actual_instance is None:
            return None

        if hasattr(self.actual_instance, "to_dict") and callable(self.actual_instance.to_dict):
            return self.actual_instance.to_dict()
        else:
            # primitive type
            return self.actual_instance

    def to_str(self) -> str:
        """Returns the string representation of the actual instance"""
        return pprint.pformat(self.model_dump())





# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from ai_stats_generated.models.message_content import MessageContent
from typing import Optional, Set
from typing_extensions import Self

class ChatMessageTool(BaseModel):
    """
    ChatMessageTool
    """ # noqa: E501
    role: StrictStr
    content: MessageContent
    name: Optional[StrictStr] = None
    tool_call_id: StrictStr
    __properties: ClassVar[List[str]] = ["role", "content", "name", "tool_call_id"]

    @field_validator('role')
    def role_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['tool']):
            raise ValueError("must be one of enum values ('tool')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChatMessageTool from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of content
        if self.content:
            _dict['content'] = self.content.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChatMessageTool from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "role": obj.get("role"),
            "content": MessageContent.from_dict(obj["content"]) if obj.get("content") is not None else None,
            "name": obj.get("name"),
            "tool_call_id": obj.get("tool_call_id")
        })
        return _obj





# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class OrganisationId(str, Enum):
    """
    Organisation identifier.
    """

    """
    allowed enum values
    """
    AI21 = 'ai21'
    AMAZON = 'amazon'
    ANTHROPIC = 'anthropic'
    BAIDU = 'baidu'
    BLACK_MINUS_FOREST_MINUS_LABS = 'black-forest-labs'
    BYTEDANCE = 'bytedance'
    COHERE = 'cohere'
    DEEPSEEK = 'deepseek'
    ELEVEN_MINUS_LABS = 'eleven-labs'
    GOOGLE = 'google'
    IBM = 'ibm'
    INCLUSIONAI = 'inclusionai'
    LG = 'lg'
    META = 'meta'
    MICROSOFT = 'microsoft'
    MINIMAX = 'minimax'
    MISTRAL = 'mistral'
    MOONSHOTAI = 'moonshotai'
    NOUS = 'nous'
    NVIDIA = 'nvidia'
    OPENAI = 'openai'
    PERPLEXITY = 'perplexity'
    QWEN = 'qwen'
    SUNO = 'suno'
    X_MINUS_AI = 'x-ai'
    Z_MINUS_AI = 'z-ai'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of OrganisationId from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from ai_stats_generated.models.chat_completions_request_reasoning import ChatCompletionsRequestReasoning
from ai_stats_generated.models.chat_completions_request_tool_choice import ChatCompletionsRequestToolChoice
from ai_stats_generated.models.chat_message import ChatMessage
from typing import Optional, Set
from typing_extensions import Self

class ChatCompletionsRequest(BaseModel):
    """
    ChatCompletionsRequest
    """ # noqa: E501
    reasoning: Optional[ChatCompletionsRequestReasoning] = None
    frequency_penalty: Optional[Union[Annotated[float, Field(le=2, strict=True, ge=-2)], Annotated[int, Field(le=2, strict=True, ge=-2)]]] = None
    logit_bias: Optional[Dict[str, Union[StrictFloat, StrictInt]]] = None
    max_output_tokens: Optional[Annotated[int, Field(strict=True, ge=1)]] = None
    max_completions_tokens: Optional[Annotated[int, Field(strict=True, ge=1)]] = None
    meta: Optional[StrictBool] = Field(default=False, description="Include gateway metadata in the response.")
    model: StrictStr
    messages: Annotated[List[ChatMessage], Field(min_length=1)]
    presence_penalty: Optional[Union[Annotated[float, Field(le=2, strict=True, ge=-2)], Annotated[int, Field(le=2, strict=True, ge=-2)]]] = None
    seed: Optional[Annotated[int, Field(le=9223372036854776000, strict=True, ge=-9223372036854776000)]] = None
    stream: Optional[StrictBool] = False
    temperature: Optional[Union[Annotated[float, Field(le=2, strict=True, ge=0)], Annotated[int, Field(le=2, strict=True, ge=0)]]] = None
    tools: Optional[List[Dict[str, Any]]] = None
    max_tool_calls: Optional[Annotated[int, Field(strict=True, ge=1)]] = None
    parallel_tool_calls: Optional[StrictBool] = True
    tool_choice: Optional[ChatCompletionsRequestToolChoice] = None
    logprobs: Optional[StrictBool] = None
    top_logprobs: Optional[Annotated[int, Field(le=20, strict=True, ge=0)]] = None
    top_p: Optional[Union[Annotated[float, Field(le=1, strict=True, ge=0)], Annotated[int, Field(le=1, strict=True, ge=0)]]] = None
    usage: Optional[StrictBool] = Field(default=True, description="Include token usage details in the response.")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["reasoning", "frequency_penalty", "logit_bias", "max_output_tokens", "max_completions_tokens", "meta", "model", "messages", "presence_penalty", "seed", "stream", "temperature", "tools", "max_tool_calls", "parallel_tool_calls", "tool_choice", "logprobs", "top_logprobs", "top_p", "usage"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChatCompletionsRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of reasoning
        if self.reasoning:
            _dict['reasoning'] = self.reasoning.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in messages (list)
        _items = []
        if self.messages:
            for _item_messages in self.messages:
                if _item_messages:
                    _items.append(_item_messages.to_dict())
            _dict['messages'] = _items
        # override the default output from pydantic by calling `to_dict()` of tool_choice
        if self.tool_choice:
            _dict['tool_choice'] = self.tool_choice.to_dict()
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChatCompletionsRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "reasoning": ChatCompletionsRequestReasoning.from_dict(obj["reasoning"]) if obj.get("reasoning") is not None else None,
            "frequency_penalty": obj.get("frequency_penalty"),
            "logit_bias": obj.get("logit_bias"),
            "max_output_tokens": obj.get("max_output_tokens"),
            "max_completions_tokens": obj.get("max_completions_tokens"),
            "meta": obj.get("meta") if obj.get("meta") is not None else False,
            "model": obj.get("model"),
            "messages": [ChatMessage.from_dict(_item) for _item in obj["messages"]] if obj.get("messages") is not None else None,
            "presence_penalty": obj.get("presence_penalty"),
            "seed": obj.get("seed"),
            "stream": obj.get("stream") if obj.get("stream") is not None else False,
            "temperature": obj.get("temperature"),
            "tools": obj.get("tools"),
            "max_tool_calls": obj.get("max_tool_calls"),
            "parallel_tool_calls": obj.get("parallel_tool_calls") if obj.get("parallel_tool_calls") is not None else True,
            "tool_choice": ChatCompletionsRequestToolChoice.from_dict(obj["tool_choice"]) if obj.get("tool_choice") is not None else None,
            "logprobs": obj.get("logprobs"),
            "top_logprobs": obj.get("top_logprobs"),
            "top_p": obj.get("top_p"),
            "usage": obj.get("usage") if obj.get("usage") is not None else True
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictBool
from typing import Any, Optional
from typing_extensions import Annotated
from ai_stats_generated.models.model_list_response import ModelListResponse

from ai_stats_generated.api_client import ApiClient, RequestSerialized
from ai_stats_generated.api_response import ApiResponse
from ai_stats_generated.rest import RESTResponseType


class ModelsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def models_get(
        self,
        provider: Annotated[Optional[Any], Field(description="Filter results to models served by one or more provider identifiers.")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=250, strict=True, ge=1)]], Field(description="Maximum number of models to return (default 50).")] = None,
        offset: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Number of models to skip before starting the page.")] = None,
        organisation: Annotated[Optional[Any], Field(description="Restrict results to models associated with one or more organisation identifiers.")] = None,
        include_endpoints: Annotated[Optional[Any], Field(description="Only return models that support at least one of the specified gateway endpoints.")] = None,
        exclude_endpoints: Annotated[Optional[Any], Field(description="Exclude models that support any of the specified gateway endpoints.")] = None,
        input_types: Annotated[Optional[Any], Field(description="Only return models that advertise support for at least one of the requested input content types.")] = None,
        output_types: Annotated[Optional[Any], Field(description="Only return models that advertise support for at least one of the requested output content types.")] = None,
        include_rumoured: Annotated[Optional[StrictBool], Field(description="Whether to include models marked as rumoured in the response (default true).")] = None,
        include_deprecated: Annotated[Optional[StrictBool], Field(description="Whether to include models marked as deprecated in the response (default true).")] = None,
        include_retired: Annotated[Optional[StrictBool], Field(description="Whether to include models marked as retired in the response (default true).")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ModelListResponse:
        """List all gateway models

        Returns a paginated catalogue of models with provider mappings, aliases, and endpoint support. Results are sorted by release date (falling back to announcement date) in descending order.

        :param provider: Filter results to models served by one or more provider identifiers.
        :type provider: ModelsGetProviderParameter
        :param limit: Maximum number of models to return (default 50).
        :type limit: int
        :param offset: Number of models to skip before starting the page.
        :type offset: int
        :param organisation: Restrict results to models associated with one or more organisation identifiers.
        :type organisation: ModelsGetOrganisationParameter
        :param include_endpoints: Only return models that support at least one of the specified gateway endpoints.
        :type include_endpoints: ModelsGetIncludeEndpointsParameter
        :param exclude_endpoints: Exclude models that support any of the specified gateway endpoints.
        :type exclude_endpoints: ModelsGetIncludeEndpointsParameter
        :param input_types: Only return models that advertise support for at least one of the requested input content types.
        :type input_types: ModelsGetProviderParameter
        :param output_types: Only return models that advertise support for at least one of the requested output content types.
        :type output_types: ModelsGetProviderParameter
        :param include_rumoured: Whether to include models marked as rumoured in the response (default true).
        :type include_rumoured: bool
        :param include_deprecated: Whether to include models marked as deprecated in the response (default true).
        :type include_deprecated: bool
        :param include_retired: Whether to include models marked as retired in the response (default true).
        :type include_retired: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_get_serialize(
            provider=provider,
            limit=limit,
            offset=offset,
            organisation=organisation,
            include_endpoints=include_endpoints,
            exclude_endpoints=exclude_endpoints,
            input_types=input_types,
            output_types=output_types,
            include_rumoured=include_rumoured,
            include_deprecated=include_deprecated,
            include_retired=include_retired,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ModelListResponse",
            '401': "GatewayError",
            '429': "GatewayError",
            '500': "GatewayError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def models_get_with_http_info(
        self,
        provider: Annotated[Optional[Any], Field(description="Filter results to models served by one or more provider identifiers.")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=250, strict=True, ge=1)]], Field(description="Maximum number of models to return (default 50).")] = None,
        offset: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Number of models to skip before starting the page.")] = None,
        organisation: Annotated[Optional[Any], Field(description="Restrict results to models associated with one or more organisation identifiers.")] = None,
        include_endpoints: Annotated[Optional[Any], Field(description="Only return models that support at least one of the specified gateway endpoints.")] = None,
        exclude_endpoints: Annotated[Optional[Any], Field(description="Exclude models that support any of the specified gateway endpoints.")] = None,
        input_types: Annotated[Optional[Any], Field(description="Only return models that advertise support for at least one of the requested input content types.")] = None,
        output_types: Annotated[Optional[Any], Field(description="Only return models that advertise support for at least one of the requested output content types.")] = None,
        include_rumoured: Annotated[Optional[StrictBool], Field(description="Whether to include models marked as rumoured in the response (default true).")] = None,
        include_deprecated: Annotated[Optional[StrictBool], Field(description="Whether to include models marked as deprecated in the response (default true).")] = None,
        include_retired: Annotated[Optional[StrictBool], Field(description="Whether to include models marked as retired in the response (default true).")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ModelListResponse]:
        """List all gateway models

        Returns a paginated catalogue of models with provider mappings, aliases, and endpoint support. Results are sorted by release date (falling back to announcement date) in descending order.

        :param provider: Filter results to models served by one or more provider identifiers.
        :type provider: ModelsGetProviderParameter
        :param limit: Maximum number of models to return (default 50).
        :type limit: int
        :param offset: Number of models to skip before starting the page.
        :type offset: int
        :param organisation: Restrict results to models associated with one or more organisation identifiers.
        :type organisation: ModelsGetOrganisationParameter
        :param include_endpoints: Only return models that support at least one of the specified gateway endpoints.
        :type include_endpoints: ModelsGetIncludeEndpointsParameter
        :param exclude_endpoints: Exclude models that support any of the specified gateway endpoints.
        :type exclude_endpoints: ModelsGetIncludeEndpointsParameter
        :param input_types: Only return models that advertise support for at least one of the requested input content types.
        :type input_types: ModelsGetProviderParameter
        :param output_types: Only return models that advertise support for at least one of the requested output content types.
        :type output_types: ModelsGetProviderParameter
        :param include_rumoured: Whether to include models marked as rumoured in the response (default true).
        :type include_rumoured: bool
        :param include_deprecated: Whether to include models marked as deprecated in the response (default true).
        :type include_deprecated: bool
        :param include_retired: Whether to include models marked as retired in the response (default true).
        :type include_retired: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_get_serialize(
            provider=provider,
            limit=limit,
            offset=offset,
            organisation=organisation,
            include_endpoints=include_endpoints,
            exclude_endpoints=exclude_endpoints,
            input_types=input_types,
            output_types=output_types,
            include_rumoured=include_rumoured,
            include_deprecated=include_deprecated,
            include_retired=include_retired,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ModelListResponse",
            '401': "GatewayError",
            '429': "GatewayError",
            '500': "GatewayError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def models_get_without_preload_content(
        self,
        provider: Annotated[Optional[Any], Field(description="Filter results to models served by one or more provider identifiers.")] = None,
        limit: Annotated[Optional[Annotated[int, Field(le=250, strict=True, ge=1)]], Field(description="Maximum number of models to return (default 50).")] = None,
        offset: Annotated[Optional[Annotated[int, Field(strict=True, ge=0)]], Field(description="Number of models to skip before starting the page.")] = None,
        organisation: Annotated[Optional[Any], Field(description="Restrict results to models associated with one or more organisation identifiers.")] = None,
        include_endpoints: Annotated[Optional[Any], Field(description="Only return models that support at least one of the specified gateway endpoints.")] = None,
        exclude_endpoints: Annotated[Optional[Any], Field(description="Exclude models that support any of the specified gateway endpoints.")] = None,
        input_types: Annotated[Optional[Any], Field(description="Only return models that advertise support for at least one of the requested input content types.")] = None,
        output_types: Annotated[Optional[Any], Field(description="Only return models that advertise support for at least one of the requested output content types.")] = None,
        include_rumoured: Annotated[Optional[StrictBool], Field(description="Whether to include models marked as rumoured in the response (default true).")] = None,
        include_deprecated: Annotated[Optional[StrictBool], Field(description="Whether to include models marked as deprecated in the response (default true).")] = None,
        include_retired: Annotated[Optional[StrictBool], Field(description="Whether to include models marked as retired in the response (default true).")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List all gateway models

        Returns a paginated catalogue of models with provider mappings, aliases, and endpoint support. Results are sorted by release date (falling back to announcement date) in descending order.

        :param provider: Filter results to models served by one or more provider identifiers.
        :type provider: ModelsGetProviderParameter
        :param limit: Maximum number of models to return (default 50).
        :type limit: int
        :param offset: Number of models to skip before starting the page.
        :type offset: int
        :param organisation: Restrict results to models associated with one or more organisation identifiers.
        :type organisation: ModelsGetOrganisationParameter
        :param include_endpoints: Only return models that support at least one of the specified gateway endpoints.
        :type include_endpoints: ModelsGetIncludeEndpointsParameter
        :param exclude_endpoints: Exclude models that support any of the specified gateway endpoints.
        :type exclude_endpoints: ModelsGetIncludeEndpointsParameter
        :param input_types: Only return models that advertise support for at least one of the requested input content types.
        :type input_types: ModelsGetProviderParameter
        :param output_types: Only return models that advertise support for at least one of the requested output content types.
        :type output_types: ModelsGetProviderParameter
        :param include_rumoured: Whether to include models marked as rumoured in the response (default true).
        :type include_rumoured: bool
        :param include_deprecated: Whether to include models marked as deprecated in the response (default true).
        :type include_deprecated: bool
        :param include_retired: Whether to include models marked as retired in the response (default true).
        :type include_retired: bool
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._models_get_serialize(
            provider=provider,
            limit=limit,
            offset=offset,
            organisation=organisation,
            include_endpoints=include_endpoints,
            exclude_endpoints=exclude_endpoints,
            input_types=input_types,
            output_types=output_types,
            include_rumoured=include_rumoured,
            include_deprecated=include_deprecated,
            include_retired=include_retired,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "ModelListResponse",
            '401': "GatewayError",
            '429': "GatewayError",
            '500': "GatewayError",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _models_get_serialize(
        self,
        provider,
        limit,
        offset,
        organisation,
        include_endpoints,
        exclude_endpoints,
        input_types,
        output_types,
        include_rumoured,
        include_deprecated,
        include_retired,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if provider is not None:
            
            _query_params.append(('provider', provider))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if organisation is not None:
            
            _query_params.append(('organisation', organisation))
            
        if include_endpoints is not None:
            
            _query_params.append(('include_endpoints', include_endpoints))
            
        if exclude_endpoints is not None:
            
            _query_params.append(('exclude_endpoints', exclude_endpoints))
            
        if input_types is not None:
            
            _query_params.append(('input_types', input_types))
            
        if output_types is not None:
            
            _query_params.append(('output_types', output_types))
            
        if include_rumoured is not None:
            
            _query_params.append(('include_rumoured', include_rumoured))
            
        if include_deprecated is not None:
            
            _query_params.append(('include_deprecated', include_deprecated))
            
        if include_retired is not None:
            
            _query_params.append(('include_retired', include_retired))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'GatewayAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/models',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List
from ai_stats_generated.models.gateway_health_provider import GatewayHealthProvider
from ai_stats_generated.models.gateway_health_response_overall import GatewayHealthResponseOverall
from ai_stats_generated.models.gateway_health_response_scope import GatewayHealthResponseScope
from typing import Optional, Set
from typing_extensions import Self

class GatewayHealthResponse(BaseModel):
    """
    GatewayHealthResponse
    """ # noqa: E501
    ok: StrictBool
    window_minutes: StrictInt
    scope: GatewayHealthResponseScope
    overall: GatewayHealthResponseOverall
    providers: List[GatewayHealthProvider]
    generated_at: StrictInt = Field(description="Unix timestamp in milliseconds.")
    __properties: ClassVar[List[str]] = ["ok", "window_minutes", "scope", "overall", "providers", "generated_at"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GatewayHealthResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of scope
        if self.scope:
            _dict['scope'] = self.scope.to_dict()
        # override the default output from pydantic by calling `to_dict()` of overall
        if self.overall:
            _dict['overall'] = self.overall.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in providers (list)
        _items = []
        if self.providers:
            for _item_providers in self.providers:
                if _item_providers:
                    _items.append(_item_providers.to_dict())
            _dict['providers'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GatewayHealthResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "ok": obj.get("ok"),
            "window_minutes": obj.get("window_minutes"),
            "scope": GatewayHealthResponseScope.from_dict(obj["scope"]) if obj.get("scope") is not None else None,
            "overall": GatewayHealthResponseOverall.from_dict(obj["overall"]) if obj.get("overall") is not None else None,
            "providers": [GatewayHealthProvider.from_dict(_item) for _item in obj["providers"]] if obj.get("providers") is not None else None,
            "generated_at": obj.get("generated_at")
        })
        return _obj





# coding: utf-8

# flake8: noqa
"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from ai_stats_generated.models.benchmark_id import BenchmarkId
from ai_stats_generated.models.chat_completions_request import ChatCompletionsRequest
from ai_stats_generated.models.chat_completions_request_reasoning import ChatCompletionsRequestReasoning
from ai_stats_generated.models.chat_completions_request_tool_choice import ChatCompletionsRequestToolChoice
from ai_stats_generated.models.chat_completions_response import ChatCompletionsResponse
from ai_stats_generated.models.chat_message import ChatMessage
from ai_stats_generated.models.chat_message_assistant import ChatMessageAssistant
from ai_stats_generated.models.chat_message_system import ChatMessageSystem
from ai_stats_generated.models.chat_message_tool import ChatMessageTool
from ai_stats_generated.models.chat_message_user import ChatMessageUser
from ai_stats_generated.models.gateway_chat_choice import GatewayChatChoice
from ai_stats_generated.models.gateway_chat_choice_message import GatewayChatChoiceMessage
from ai_stats_generated.models.gateway_error import GatewayError
from ai_stats_generated.models.gateway_error_meta import GatewayErrorMeta
from ai_stats_generated.models.gateway_generation_record import GatewayGenerationRecord
from ai_stats_generated.models.gateway_health_provider import GatewayHealthProvider
from ai_stats_generated.models.gateway_health_response import GatewayHealthResponse
from ai_stats_generated.models.gateway_health_response_overall import GatewayHealthResponseOverall
from ai_stats_generated.models.gateway_health_response_scope import GatewayHealthResponseScope
from ai_stats_generated.models.gateway_image_data import GatewayImageData
from ai_stats_generated.models.gateway_metadata import GatewayMetadata
from ai_stats_generated.models.gateway_model import GatewayModel
from ai_stats_generated.models.gateway_model_provider import GatewayModelProvider
from ai_stats_generated.models.gateway_organisation import GatewayOrganisation
from ai_stats_generated.models.gateway_response_envelope import GatewayResponseEnvelope
from ai_stats_generated.models.gateway_usage import GatewayUsage
from ai_stats_generated.models.image_generation_request import ImageGenerationRequest
from ai_stats_generated.models.image_generation_response import ImageGenerationResponse
from ai_stats_generated.models.message_content import MessageContent
from ai_stats_generated.models.message_content_image_url import MessageContentImageUrl
from ai_stats_generated.models.message_content_image_url_image_url import MessageContentImageUrlImageUrl
from ai_stats_generated.models.message_content_input_audio import MessageContentInputAudio
from ai_stats_generated.models.message_content_input_audio_input_audio import MessageContentInputAudioInputAudio
from ai_stats_generated.models.message_content_input_video import MessageContentInputVideo
from ai_stats_generated.models.message_content_part import MessageContentPart
from ai_stats_generated.models.message_content_text import MessageContentText
from ai_stats_generated.models.model_id import ModelId
from ai_stats_generated.models.model_list_response import ModelListResponse
from ai_stats_generated.models.models_get_include_endpoints_parameter import ModelsGetIncludeEndpointsParameter
from ai_stats_generated.models.models_get_organisation_parameter import ModelsGetOrganisationParameter
from ai_stats_generated.models.models_get_provider_parameter import ModelsGetProviderParameter
from ai_stats_generated.models.moderation_input_content_item import ModerationInputContentItem
from ai_stats_generated.models.moderation_input_image_url_item import ModerationInputImageUrlItem
from ai_stats_generated.models.moderation_input_image_url_item_image_url import ModerationInputImageUrlItemImageUrl
from ai_stats_generated.models.moderation_input_text_item import ModerationInputTextItem
from ai_stats_generated.models.moderation_request import ModerationRequest
from ai_stats_generated.models.moderation_request_input import ModerationRequestInput
from ai_stats_generated.models.moderation_response import ModerationResponse
from ai_stats_generated.models.moderation_result import ModerationResult
from ai_stats_generated.models.organisation_id import OrganisationId
from ai_stats_generated.models.tool_call import ToolCall
from ai_stats_generated.models.tool_call_function import ToolCallFunction
from ai_stats_generated.models.tool_call_part import ToolCallPart
from ai_stats_generated.models.video_generation_request import VideoGenerationRequest
from ai_stats_generated.models.video_generation_response import VideoGenerationResponse




# coding: utf-8

"""
    AI Stats Gateway API

    Programmatic access to the AI Stats AI Gateway. All endpoints forward requests to the best available provider for the specified model, and return normalised responses with clear structured metadata.

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BenchmarkId(str, Enum):
    """
    Benchmark identifier.
    """

    """
    allowed enum values
    """
    ACE_MINUS_BENCH = 'ace-bench'
    AI2_MINUS_SCIARENA = 'ai2-sciarena'
    AI2D = 'ai2d'
    AIDANBENCH = 'aidanbench'
    AIDER_MINUS_POLYGLOT = 'aider-polyglot'
    AIME_MINUS_2024 = 'aime-2024'
    AIME_MINUS_2025 = 'aime-2025'
    ARC_MINUS_AGI_MINUS_1 = 'arc-agi-1'
    ARC_MINUS_AGI_MINUS_2 = 'arc-agi-2'
    AUTOLOGI = 'autologi'
    BALROG_MINUS_AI = 'balrog-ai'
    BIGCODEBENCH = 'bigcodebench'
    BROWSECOMP = 'browsecomp'
    BROWSECOMP_MINUS_LONG_MINUS_CONTEXT_MINUS_128K = 'browsecomp-long-context-128k'
    BROWSECOMP_MINUS_LONG_MINUS_CONTEXT_MINUS_256K = 'browsecomp-long-context-256k'
    C_MINUS_EVAL = 'c-eval'
    CHARTQA = 'chartqa'
    CHARXIV_MINUS_REASONING = 'charxiv-reasoning'
    CNMO_MINUS_2024 = 'cnmo-2024'
    CODEFORCES = 'codeforces'
    COLLIE = 'collie'
    CONFABULATIONS = 'confabulations'
    CREATIVE_MINUS_STORY_MINUS_WRITING = 'creative-story-writing'
    CSIMPLEQA = 'csimpleqa'
    DOCVQA = 'docvqa'
    DUBESOR_MINUS_LLM = 'dubesor-llm'
    ELIMINATION_MINUS_GAME = 'elimination-game'
    EQBENCH = 'eqbench'
    ERQA = 'erqa'
    EVALPLUS = 'evalplus'
    FACTS = 'facts'
    FACTS_MINUS_BENCHMARK_MINUS_SUITE = 'facts-benchmark-suite'
    FACTSCORE_MINUS_HALLUCIATION_MINUS_RATE = 'factscore-halluciation-rate'
    FICTION_MINUS_LIVE_MINUS_BENCH = 'fiction-live-bench'
    FRONTIER_MINUS_MATH = 'frontier-math'
    GALILEO_MINUS_AGENT = 'galileo-agent'
    GLOBAL_MINUS_PICA = 'global-pica'
    GPQA = 'gpqa'
    GPQA_MINUS_DIAMOND = 'gpqa-diamond'
    GRAPHWALKS_MINUS_BFS_MINUS_LT_MINUS_128K = 'graphwalks-bfs-lt-128k'
    GRAPHWALKS_MINUS_PARENTS_MINUS_LT_MINUS_128K = 'graphwalks-parents-lt-128k'
    GSM8K = 'gsm8k'
    HEALTHBENCH = 'healthbench'
    HEALTHBENCH_MINUS_CONCENSUS = 'healthbench-concensus'
    HEALTHBENCH_MINUS_HARD = 'healthbench-hard'
    HMMT_MINUS_2025 = 'hmmt-2025'
    HUMANEVAL = 'humaneval'
    HUMANITYS_MINUS_LAST_MINUS_EXAM = 'humanitys-last-exam'
    IF_MINUS_EVAL = 'if-eval'
    IQ_MINUS_BENCH = 'iq-bench'
    LISANBENCH = 'lisanbench'
    LIVEBENCH = 'livebench'
    LIVECODEBENCH_MINUS_PRO = 'livecodebench-pro'
    LIVECODEBENCH_MINUS_V5 = 'livecodebench-v5'
    LIVECODEBENCH_MINUS_V6 = 'livecodebench-v6'
    LMARENA_MINUS_TEXT = 'lmarena-text'
    LMARENA_MINUS_WEBDEV = 'lmarena-webdev'
    LONGFACT_MINUS_CONCEPTS_MINUS_HALLUCINATION_MINUS_RATE = 'longfact-concepts-hallucination-rate'
    LONGFACT_MINUS_OBJECTS_MINUS_HALLUCINATION_MINUS_RATE = 'longfact-objects-hallucination-rate'
    MATH = 'math'
    MATH_MINUS_500 = 'math-500'
    MATHARENA = 'matharena'
    MATHARENA_MINUS_APEX = 'matharena-apex'
    MATHVISTA = 'mathvista'
    MC_MINUS_BENCH = 'mc-bench'
    METR = 'metr'
    MISGUIDED_MINUS_ATTENTION = 'misguided-attention'
    MLE_MINUS_BENCH = 'mle-bench'
    MMLU = 'mmlu'
    MMLU_MINUS_PRO = 'mmlu-pro'
    MMLU_MINUS_REDUX = 'mmlu-redux'
    MMLU_MINUS_REDUX_MINUS_2_DOT_0 = 'mmlu-redux-2.0'
    MMMLU = 'mmmlu'
    MMMU = 'mmmu'
    MMMU_MINUS_PRO = 'mmmu-pro'
    MULTI_MINUS_CHALLENGE = 'multi-challenge'
    MULTI_PL_MINUS_E = 'multiPL-E'
    NYT_MINUS_CONNECTIONS = 'nyt-connections'
    OJBENCH = 'ojbench'
    OMNIDOCBENCH_MINUS_1_DOT_5 = 'omnidocbench-1.5'
    OPENAI_MINUS_MRCR_MINUS_2_MINUS_NEEDLE_MINUS_128K = 'openai-mrcr-2-needle-128k'
    OPENAI_MINUS_MRCR_MINUS_2_MINUS_NEEDLE_MINUS_256K = 'openai-mrcr-2-needle-256k'
    OPENAI_MINUS_MRCR_MINUS_8_MINUS_NEEDLE_MINUS_128K = 'openai-mrcr-8-needle-128k'
    OPENAI_MINUS_MRCR_MINUS_8_MINUS_NEEDLE_MINUS_1M = 'openai-mrcr-8-needle-1m'
    OS_MINUS_WORLD = 'os-world'
    PAPERBENCH = 'paperbench'
    PHYBENCH = 'phybench'
    POLYMATH_MINUS_EN = 'polymath-en'
    SCREENSPOT_MINUS_PRO = 'screenspot-pro'
    SEAL_MINUS_MULTICHALLENEGE = 'seal-multichallenege'
    SIMPLEBENCH = 'simplebench'
    SIMPLEQA = 'simpleqa'
    SMOLAGENTS_MINUS_LLM = 'smolagents-llm'
    SNAKE_MINUS_BENCH = 'snake-bench'
    SOLO_MINUS_BENCH = 'solo-bench'
    SUPERGPQA = 'supergpqa'
    SWE_MINUS_BENCH = 'swe-bench'
    SWE_MINUS_BENCH_MINUS_LIVE = 'swe-bench-live'
    SWE_MINUS_BENCH_MINUS_MULTILINGUAL = 'swe-bench-multilingual'
    SWE_MINUS_BENCH_MINUS_PRO = 'swe-bench-pro'
    SWE_MINUS_LANCER = 'swe-lancer'
    SYMFLOWER_MINUS_CODING = 'symflower-coding'
    TAU_MINUS_2_MINUS_AIRLINE = 'tau-2-airline'
    TAU_MINUS_2_MINUS_BENCH = 'tau-2-bench'
    TAU_MINUS_2_MINUS_RETAIL = 'tau-2-retail'
    TAU_MINUS_2_MINUS_TELECOM = 'tau-2-telecom'
    TAU_MINUS_BENCH = 'tau-bench'
    TAU_MINUS_BENCH_MINUS_AIRLINE = 'tau-bench-airline'
    TAU_MINUS_BENCH_MINUS_RETAIL = 'tau-bench-retail'
    TERMINAL_MINUS_BENCH = 'terminal-bench'
    TERMINAL_MINUS_BENCH_MINUS_2_DOT_0 = 'terminal-bench-2.0'
    THEMATIC_MINUS_GENERALISATION = 'thematic-generalisation'
    TRIVIAQA = 'triviaqa'
    USAMO_MINUS_2025 = 'usamo-2025'
    VENDING_MINUS_BENCH_MINUS_2 = 'vending-bench-2'
    VIDEO_MINUS_MMMU = 'video-mmmu'
    VIDEOMME = 'videomme'
    WEIRDML = 'weirdml'
    XLANG_MINUS_AGENT = 'xlang-agent'
    ZEBRALOGIC = 'zebralogic'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BenchmarkId from a JSON string"""
        return cls(json.loads(json_str))





from __future__ import annotations

from typing import Any, Dict, Iterator, Optional, Union
from typing_extensions import NotRequired, TypedDict

from ai_stats_generated import ApiClient, Configuration
from ai_stats_generated.api.completions_api import CompletionsApi
from ai_stats_generated.api.images_api import ImagesApi
from ai_stats_generated.api.moderations_api import ModerationsApi
from ai_stats_generated.api.video_api import VideoApi
from ai_stats_generated.models.model_list_response import ModelListResponse
from ai_stats_generated.models.gateway_health_response import GatewayHealthResponse
from ai_stats_generated.models.chat_completions_request import ChatCompletionsRequest
from ai_stats_generated.models.chat_completions_response import ChatCompletionsResponse
from ai_stats_generated.models.chat_completions_request_reasoning import ChatCompletionsRequestReasoning
from ai_stats_generated.models.chat_completions_request_tool_choice import ChatCompletionsRequestToolChoice
from ai_stats_generated.models.chat_message import ChatMessage
from ai_stats_generated.models.model_id import ModelId
from ai_stats_generated.models.image_generation_request import ImageGenerationRequest
from ai_stats_generated.models.image_generation_response import ImageGenerationResponse
from ai_stats_generated.models.moderation_request import ModerationRequest
from ai_stats_generated.models.moderation_response import ModerationResponse
from ai_stats_generated.models.video_generation_request import VideoGenerationRequest
from ai_stats_generated.models.video_generation_response import VideoGenerationResponse

import httpx

DEFAULT_BASE_URL = "https://api.ai-stats.phaseo.app/v1"


class ChatCompletionsParams(TypedDict, total=False):
    reasoning: NotRequired[list[ChatCompletionsRequestReasoning]]
    frequency_penalty: NotRequired[Union[float, int]]
    logit_bias: NotRequired[Dict[str, Union[float, int]]]
    max_output_tokens: NotRequired[int]
    max_completions_tokens: NotRequired[int]
    meta: NotRequired[bool]
    model: ModelId
    messages: list[ChatMessage]
    presence_penalty: NotRequired[Union[float, int]]
    seed: NotRequired[int]
    stream: NotRequired[bool]
    temperature: NotRequired[Union[float, int]]
    tools: NotRequired[list[dict[str, Any]]]
    max_tool_calls: NotRequired[int]
    parallel_tool_calls: NotRequired[bool]
    tool_choice: NotRequired[ChatCompletionsRequestToolChoice]
    top_k: NotRequired[int]
    logprobs: NotRequired[bool]
    top_logprobs: NotRequired[int]
    top_p: NotRequired[Union[float, int]]
    usage: NotRequired[bool]


MODEL_IDS: tuple[ModelId, ...] = tuple(ModelId)


class AIStats:
    def __init__(self, api_key: str, base_url: Optional[str] = None, timeout: Optional[float] = None):
        if not api_key:
            raise ValueError("api_key is required")

        host = (base_url or DEFAULT_BASE_URL).rstrip("/")
        self._base_url = host
        self._headers = {"Authorization": f"Bearer {api_key}"}
        configuration = Configuration(
            host=host,
            api_key={"GatewayAuth": f"Bearer {api_key}"},
        )
        if timeout is not None:
            configuration.timeout = timeout

        self._client = ApiClient(configuration=configuration)
        self._chat_api = CompletionsApi(api_client=self._client)
        self._images_api = ImagesApi(api_client=self._client)
        self._moderations_api = ModerationsApi(api_client=self._client)
        self._video_api = VideoApi(api_client=self._client)

    def generate_text(self, request: ChatCompletionsRequest | ChatCompletionsParams) -> ChatCompletionsResponse:
        payload = request if isinstance(request, ChatCompletionsRequest) else ChatCompletionsRequest.model_validate({**request, "stream": False})
        return self._chat_api.create_chat_completion(chat_completions_request=payload)

    def stream_text(self, request: ChatCompletionsRequest | ChatCompletionsParams) -> Iterator[str]:
        payload = request if isinstance(request, ChatCompletionsRequest) else ChatCompletionsRequest.model_validate({**request, "stream": True})
        client_timeout = self._client.configuration.timeout or None
        with httpx.stream(
            "POST",
            f"{self._base_url}/chat/completions",
            headers={**self._headers, "Content-Type": "application/json"},
            json=payload.model_dump(by_alias=True),
            timeout=client_timeout,
        ) as resp:
            resp.raise_for_status()
            for line in resp.iter_lines():
                if not line:
                    continue
                yield line.decode("utf-8") if isinstance(line, (bytes, bytearray)) else str(line)

    def generate_image(self, request: ImageGenerationRequest) -> ImageGenerationResponse:
        return self._images_api.images_generations_post(image_generation_request=request)

    def generate_moderation(self, request: ModerationRequest) -> ModerationResponse:
        return self._moderations_api.moderations_post(request)

    def generate_video(self, request: VideoGenerationRequest) -> VideoGenerationResponse:
        return self._video_api.video_generation_post(video_generation_request=request)

    def generate_transcription(self, body: dict[str, Any]) -> Any:
        client_timeout = self._client.configuration.timeout or None
        resp = httpx.post(
            f"{self._base_url}/audio/transcriptions",
            headers={**self._headers, "Content-Type": "application/json"},
            json=body,
            timeout=client_timeout,
        )
        resp.raise_for_status()
        return resp.json()

    def generate_speech(self, body: dict[str, Any]) -> Any:
        client_timeout = self._client.configuration.timeout or None
        resp = httpx.post(
            f"{self._base_url}/audio/speech",
            headers={**self._headers, "Content-Type": "application/json"},
            json=body,
            timeout=client_timeout,
        )
        resp.raise_for_status()
        return resp.json()

    def get_models(self, params: dict[str, Any] | None = None) -> ModelListResponse:
        params = params or {}
        resp = httpx.get(
            f"{self._base_url}/models",
            headers=self._headers,
            params=params,
            timeout=self._client.configuration.timeout or None,
        )
        resp.raise_for_status()
        return ModelListResponse.model_validate(resp.json())

    def get_health(self, params: dict[str, Any] | None = None) -> GatewayHealthResponse:
        params = params or {}
        resp = httpx.get(
            f"{self._base_url}/health",
            headers=self._headers,
            params=params,
            timeout=self._client.configuration.timeout or None,
        )
        resp.raise_for_status()
        return GatewayHealthResponse.model_validate(resp.json())

    def get_generation(self, generation_id: str) -> Any:
        resp = httpx.get(
            f"{self._base_url}/generations/{generation_id}",
            headers=self._headers,
            timeout=self._client.configuration.timeout or None,
        )
        resp.raise_for_status()
        return resp.json()


__all__ = [
    "AIStats",
    "ChatCompletionsRequest",
    "ChatCompletionsResponse",
    "ChatCompletionsParams",
    "MODEL_IDS",
    "ModelId",
    "ImageGenerationRequest",
    "ImageGenerationResponse",
    "ModerationRequest",
    "ModerationResponse",
    "VideoGenerationRequest",
    "VideoGenerationResponse",
    "ChatMessage",
    "ChatCompletionsRequestReasoning",
]
